class MissionVariables:

    @classmethod
    def CreateExCheckTemplate(cls):
        cls.TYPE = None
        cls.TOOL = None
        cls.NAME = None
        cls.AUTHORUID = None
        return cls

